EncryptionKey

Struct EncryptionKey 

pub struct EncryptionKey {
    pub pubk: [u8; 32],
    pub salt: [u8; 16],
}
A Public Key & Salt pair that can be used for simmetric encryption, compatible with ChaCha20Poly1305

Example

use walleth::EncryptionKey;
 
let key = EncryptionKey::new(b"password", 1000); // 1000 rounds

Fields

pubk: [u8; 32]salt: [u8; 16]

Implementations

Source

impl EncryptionKey

pub fn new(password: &[u8], rounds: u32) -> Self

Create a new EncryptionKey from a password and a number of rounds

pub fn with_salt(password: &[u8], salt: [u8; 16], rounds: u32) -> Self

Create a new EncryptionKey from a password and a salt, and passing a number of rounds